@@ -375,6 +375,13 @@
     format_warning(sprintf("%s ignores effects of dispersion model.", name_fun))
   }
 
+  # fix rank deficiency
+  rankdef <- is.na(vals$beta)
+  if (any(rankdef)) {
+    rankdef_names <- names(vals$beta)[rankdef]
+    vals$beta <- vals$beta[setdiff(names(vals$beta), rankdef_names)]
+  }
+
   vals
 }
 
