@@ -63,7 +63,7 @@ find_parameters.BGGM <- function(x,
   l <- compact_list(l)
 
   if (flatten) {
-    unique(unlist(l))
+    unique(unlist(l, use.names = FALSE))
   } else {
     l
   }
@@ -110,13 +110,13 @@ find_parameters.BFBayesFactor <- function(x,
         } else {
           sprintf("%s-%s", i, i)
         }
-      }))
+      }), use.names = FALSE)
     }
 
     # add interaction terms to conditional
     if ("conditional" %in% names(interactions)) {
       for (i in interactions$conditional) {
-        conditional <- c(conditional, params[grepl(paste0("^\\Q", i, "\\E"), params)])
+        conditional <- c(conditional, grep(paste0("^\\Q", i, "\\E"), params, value = TRUE))
       }
     }
 
@@ -127,7 +127,7 @@ find_parameters.BFBayesFactor <- function(x,
         } else {
           sprintf("%s-%s", i, i)
         }
-      }))
+      }), use.names = FALSE)
     }
 
     extra <- setdiff(params, c(conditional, random))
@@ -138,7 +138,7 @@ find_parameters.BFBayesFactor <- function(x,
   l <- compact_list(l[elements])
 
   if (flatten) {
-    unique(unlist(l))
+    unique(unlist(l, use.names = FALSE))
   } else {
     l
   }
@@ -171,7 +171,7 @@ find_parameters.MCMCglmm <- function(x,
 find_parameters.mcmc.list <- function(x, flatten = FALSE, ...) {
   l <- list(conditional = colnames(x[[1]]))
   if (flatten) {
-    unique(unlist(l))
+    unique(unlist(l, use.names = FALSE))
   } else {
     l
   }
@@ -191,9 +191,9 @@ find_parameters.bamlss <- function(x,
 
   ignore <- grepl("(\\.alpha|logLik|\\.accepted|\\.edf)$", cn)
   cond <- cn[grepl("^(mu\\.p\\.|pi\\.p\\.)", cn) & !ignore]
-  sigma <- cn[grepl("^sigma\\.p\\.", cn) & !ignore]
+  sigma <- cn[startsWith(cn, "sigma.p.") & !ignore]
   smooth_terms <- cn[grepl("^mu\\.s\\.(.*)(\\.tau\\d+|\\.edf)$", cn)]
-  alpha <- cn[grepl("\\.alpha$", cn)]
+  alpha <- cn[endsWith(cn, ".alpha")]
 
   elements <- .get_elements(effects = "all", component = component)
   l <- compact_list(list(
@@ -206,7 +206,7 @@ find_parameters.bamlss <- function(x,
   l <- .filter_pars(l, parameters)
 
   if (flatten) {
-    unique(unlist(l))
+    unique(unlist(l, use.names = FALSE))
   } else {
     l
   }
@@ -223,33 +223,33 @@ find_parameters.brmsfit <- function(x,
                                     parameters = NULL,
                                     ...) {
   effects <- match.arg(effects, choices = c("all", "fixed", "random"))
-  component <- match.arg(component, choices = c("all", .all_elements()))
+  component <- match.arg(component, choices = c("all", .all_elements(), "location", "distributional"))
 
   fe <- dimnames(x$fit)$parameters
   # fe <- colnames(as.data.frame(x))
 
   # remove redundant columns. These seem to be new since brms 2.16?
-  pattern <- c("^[A-z]_\\d\\.\\d\\.(.*)")
+  pattern <- "^[A-z]_\\d\\.\\d\\.(.*)"
   fe <- fe[!grepl(pattern, fe, perl = TRUE)]
 
   is_mv <- NULL
 
   # remove "Intercept"
-  fe <- fe[!grepl("^Intercept", fe)]
+  fe <- fe[!startsWith(fe, "Intercept")]
 
   cond <- fe[grepl("^(b_|bs_|bsp_|bcs_)(?!zi_)(.*)", fe, perl = TRUE)]
   zi <- fe[grepl("^(b_zi_|bs_zi_|bsp_zi_|bcs_zi_)", fe, perl = TRUE)]
-  rand <- fe[grepl("(?!.*__(zi|sigma|beta))(?=.*^r_)", fe, perl = TRUE) & !grepl("^prior_", fe, perl = TRUE)]
+  rand <- fe[grepl("(?!.*__(zi|sigma|beta))(?=.*^r_)", fe, perl = TRUE) & !startsWith(fe, "prior_")]
   randzi <- fe[grepl("^r_(.*__zi)", fe, perl = TRUE)]
   rand_sd <- fe[grepl("(?!.*_zi)(?=.*^sd_)", fe, perl = TRUE)]
   randzi_sd <- fe[grepl("^sd_(.*_zi)", fe, perl = TRUE)]
   rand_cor <- fe[grepl("(?!.*_zi)(?=.*^cor_)", fe, perl = TRUE)]
   randzi_cor <- fe[grepl("^cor_(.*_zi)", fe, perl = TRUE)]
-  simo <- fe[grepl("^simo_", fe, perl = TRUE)]
+  simo <- fe[startsWith(fe, "simo_")]
   car_struc <- fe[fe %in% c("car", "sdcar")]
-  smooth_terms <- fe[grepl("^sds_", fe, perl = TRUE)]
-  priors <- fe[grepl("^prior_", fe, perl = TRUE)]
-  sigma <- fe[grepl("^sigma_", fe, perl = TRUE) | grepl("sigma", fe, fixed = TRUE)]
+  smooth_terms <- fe[startsWith(fe, "sds_")]
+  priors <- fe[startsWith(fe, "prior_")]
+  sigma <- fe[startsWith(fe, "sigma_") | grepl("sigma", fe, fixed = TRUE)]
   randsigma <- fe[grepl("^r_(.*__sigma)", fe, perl = TRUE)]
   beta <- fe[grepl("beta", fe, fixed = TRUE)]
   randbeta <- fe[grepl("^r_(.*__beta)", fe, perl = TRUE)]
@@ -298,7 +298,7 @@ find_parameters.brmsfit <- function(x,
       if (object_has_names(l, "random")) {
         random <- l$random[grepl(sprintf("__\\Q%s\\E\\[", i), l$random) |
           grepl(sprintf("^sd_(.*)\\Q%s\\E\\_", i), l$random) |
-          grepl("^cor_", l$random) |
+          startsWith(l$random, "cor_") |
           l$random %in% c("car", "sdcar")]
       } else {
         random <- NULL
@@ -313,7 +313,7 @@ find_parameters.brmsfit <- function(x,
       if (object_has_names(l, "zero_inflated_random")) {
         zero_inflated_random <- l$zero_inflated_random[grepl(sprintf("__zi_\\Q%s\\E\\[", i), l$zero_inflated_random) |
           grepl(sprintf("^sd_(.*)\\Q%s\\E\\_", i), l$zero_inflated_random) |
-          grepl("^cor_", l$zero_inflated_random)]
+          startsWith(l$zero_inflated_random, "cor_")]
       } else {
         zero_inflated_random <- NULL
       }
@@ -394,7 +394,7 @@ find_parameters.brmsfit <- function(x,
   attr(l, "is_mv") <- is_mv
 
   if (flatten) {
-    unique(unlist(l))
+    unique(unlist(l, use.names = FALSE))
   } else {
     l
   }
@@ -424,7 +424,7 @@ find_parameters.bayesx <- function(x,
   l <- compact_list(l[elements])
 
   if (flatten) {
-    unique(unlist(l))
+    unique(unlist(l, use.names = FALSE))
   } else {
     l
   }
@@ -445,9 +445,9 @@ find_parameters.stanreg <- function(x,
   # fe <- setdiff(dimnames(x$stanfit)$parameters, c("mean_PPD", "log-posterior"))
 
   cond <- fe[grepl("^(?!(b\\[|sigma|Sigma))", fe, perl = TRUE) & .grep_non_smoothers(fe)]
-  rand <- fe[grepl("^b\\[", fe, perl = TRUE)]
-  rand_sd <- fe[grepl("^Sigma\\[", fe, perl = TRUE)]
-  smooth_terms <- fe[grepl("^smooth_sd", fe, perl = TRUE)]
+  rand <- fe[startsWith(fe, "b[")]
+  rand_sd <- fe[startsWith(fe, "Sigma[")]
+  smooth_terms <- fe[startsWith(fe, "smooth_sd")]
   sigma <- fe[grepl("sigma", fe, fixed = TRUE)]
   auxiliary <- fe[grepl("(shape|phi|precision)", fe)]
 
@@ -470,7 +470,7 @@ find_parameters.stanreg <- function(x,
   l <- compact_list(l[elements])
 
   if (flatten) {
-    unique(unlist(l))
+    unique(unlist(l, use.names = FALSE))
   } else {
     l
   }
@@ -485,7 +485,7 @@ find_parameters.bcplm <- function(x,
                                   ...) {
   l <- .filter_pars(list(conditional = dimnames(x$sims.list[[1]])[[2]]), parameters)
   if (flatten) {
-    unique(unlist(l))
+    unique(unlist(l, use.names = FALSE))
   } else {
     l
   }
@@ -503,11 +503,11 @@ find_parameters.stanmvreg <- function(x,
   fe <- colnames(as.data.frame(x))
   rn <- names(find_response(x))
 
-  cond <- fe[grepl("^(?!(b\\[|sigma|Sigma))", fe, perl = TRUE) & .grep_non_smoothers(fe) & !grepl("\\|sigma$", fe, perl = TRUE)]
-  rand <- fe[grepl("^b\\[", fe, perl = TRUE)]
-  rand_sd <- fe[grepl("^Sigma\\[", fe, perl = TRUE)]
-  smooth_terms <- fe[grepl("^smooth_sd", fe, perl = TRUE)]
-  sigma <- fe[grepl("\\|sigma$", fe, perl = TRUE) & .grep_non_smoothers(fe)]
+  cond <- fe[grepl("^(?!(b\\[|sigma|Sigma))", fe, perl = TRUE) & .grep_non_smoothers(fe) & !endsWith(fe, "|sigma")]
+  rand <- fe[startsWith(fe, "b[")]
+  rand_sd <- fe[startsWith(fe, "Sigma[")]
+  smooth_terms <- fe[startsWith(fe, "smooth_sd")]
+  sigma <- fe[endsWith(fe, "|sigma") & .grep_non_smoothers(fe)]
   auxiliary <- fe[grepl("(shape|phi|precision)", fe)]
 
   # remove auxiliary from conditional
@@ -568,7 +568,7 @@ find_parameters.stanmvreg <- function(x,
   attr(l, "is_mv") <- "1"
 
   if (flatten) {
-    unique(unlist(l))
+    unique(unlist(l, use.names = FALSE))
   } else {
     l
   }
@@ -602,7 +602,7 @@ find_parameters.sim.merMod <- function(x,
   l <- compact_list(l[elements])
 
   if (flatten) {
-    unique(unlist(l))
+    unique(unlist(l, use.names = FALSE))
   } else {
     l
   }
@@ -618,7 +618,7 @@ find_parameters.sim <- function(x, flatten = FALSE, parameters = NULL, ...) {
   )
 
   if (flatten) {
-    unique(unlist(l))
+    unique(unlist(l, use.names = FALSE))
   } else {
     l
   }
@@ -631,7 +631,7 @@ find_parameters.mcmc <- function(x, flatten = FALSE, parameters = NULL, ...) {
   l <- .filter_pars(list(conditional = colnames(x)), parameters)
 
   if (flatten) {
-    unique(unlist(l))
+    unique(unlist(l, use.names = FALSE))
   } else {
     l
   }
@@ -644,7 +644,7 @@ find_parameters.bayesQR <- function(x, flatten = FALSE, parameters = NULL, ...)
   l <- .filter_pars(list(conditional = x[[1]]$names), parameters)
 
   if (flatten) {
-    unique(unlist(l))
+    unique(unlist(l, use.names = FALSE))
   } else {
     l
   }
@@ -661,7 +661,7 @@ find_parameters.stanfit <- function(x,
   fe <- colnames(as.data.frame(x))
 
   cond <- fe[grepl("^(?!(b\\[|sigma|Sigma|lp__))", fe, perl = TRUE) & .grep_non_smoothers(fe)]
-  rand <- fe[grepl("^b\\[", fe, perl = TRUE)]
+  rand <- fe[startsWith(fe, "b[")]
 
   l <- compact_list(list(
     conditional = cond,
@@ -675,7 +675,7 @@ find_parameters.stanfit <- function(x,
   l <- compact_list(l[elements])
 
   if (flatten) {
-    unique(unlist(l))
+    unique(unlist(l, use.names = FALSE))
   } else {
     l
   }
