@@ -934,7 +934,7 @@ get_datagrid.datagrid <- get_datagrid.visualisation_matrix
   terms <- find_terms(x, flatten = TRUE)
   factors <- grepl("^(as\\.factor|as_factor|factor|as\\.ordered|ordered)\\((.*)\\)", terms)
   if (any(factors)) {
-    factor_expressions <- lapply(terms[factors], .str2lang)
+    factor_expressions <- lapply(terms[factors], str2lang)
     cleaned_terms <- vapply(factor_expressions, all.vars, character(1))
     for (i in cleaned_terms) {
       if (is.numeric(data[[i]])) {
@@ -945,7 +945,7 @@ get_datagrid.datagrid <- get_datagrid.visualisation_matrix
   }
   logicals <- grepl("^(as\\.logical|as_logical|logical)\\((.*)\\)", terms)
   if (any(logicals)) {
-    logical_expressions <- lapply(terms[logicals], .str2lang)
+    logical_expressions <- lapply(terms[logicals], str2lang)
     cleaned_terms <- vapply(logical_expressions, all.vars, character(1))
     for (i in cleaned_terms) {
       if (is.numeric(data[[i]])) {
