@@ -23,7 +23,7 @@ get_predicted.clm <- function(x,
     type_arg <- c("prob", "class")[match(predict, valid)]
   } else {
     if (!"type" %in% names(dots)) {
-      stop("Please specify the `predict` argument.", call. = FALSE)
+      format_error("Please specify the `predict` argument.")
     } else {
       type_arg <- match.arg(dots$type, choices = c("prob", "class"))
     }
@@ -31,13 +31,13 @@ get_predicted.clm <- function(x,
 
   # hack to get predictions for all response levels
   if (is.null(data)) {
-    data <- get_data(x)
+    data <- get_data(x, verbose = FALSE)
   }
   resp <- find_response(x)
   data <- data[, setdiff(colnames(data), resp), drop = FALSE]
   vars <- as.character(attr(x$terms, "variables"))[-1]
   vars[attr(x$terms, "response")] <- resp
-  s <- paste0("list(", paste(vars, collapse = ", "), ")")
+  s <- paste0("list(", toString(vars), ")")
   new_call <- parse(text = s, keep.source = FALSE)[[1L]]
   attr(x$terms, "variables") <- new_call
 
@@ -47,13 +47,11 @@ get_predicted.clm <- function(x,
   }
 
   # check whether CIs should be returned
-  if (!is.null(ci)) {
-    if (type_arg == "class") {
-      if (verbose) {
-        format_warning("Confidence intervals are not available for classification.")
-      }
-      ci <- NULL
+  if (!is.null(ci) && type_arg == "class") {
+    if (verbose) {
+      format_warning("Confidence intervals are not available for classification.")
     }
+    ci <- NULL
   }
 
   # compute predictions
@@ -132,7 +130,7 @@ get_predicted.clm <- function(x,
 # =======================================================================
 
 #' @export
-get_predicted.multinom <- function(x, predict = "expectation", data = NULL, ci = 0.95, verbose = TRUE, ...) {
+get_predicted.multinom <- function(x, predict = "expectation", data = NULL, ci = NULL, verbose = TRUE, ...) {
   dots <- list(...)
 
   # `type` argument can be: probs | class
@@ -158,14 +156,16 @@ get_predicted.multinom <- function(x, predict = "expectation", data = NULL, ci =
   out <- .get_predicted_out(out, args = args)
 
   # add CI
-  attr(out, "ci_data") <- get_predicted_ci(
-    x,
-    predictions = out,
-    data = data,
-    ci = ci,
-    type = type_arg,
-    verbose = verbose
-  )
+  if (!is.null(ci)) {
+    attr(out, "ci_data") <- get_predicted_ci(
+      x,
+      predictions = out,
+      data = data,
+      ci = ci,
+      type = type_arg,
+      verbose = verbose
+    )
+  }
 
   out
 }
@@ -185,7 +185,7 @@ get_predicted.rlm <- function(x, predict = "expectation", ...) {
   } else {
     dots <- list(...)
     if (!"type" %in% names(dots)) {
-      stop("Please specify the `predict` argument.", call. = FALSE)
+      format_error("Please specify the `predict` argument.")
     }
     dots[["type"]] <- match.arg(dots$type, choices = "response")
     dots[["x"]] <- x
